ardt.datasets.ml.TFRecordDatasetGenerator
=========================================

.. currentmodule:: ardt.datasets.ml

.. autoclass:: TFRecordDatasetGenerator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TFRecordDatasetGenerator.__init__
      ~TFRecordDatasetGenerator.generate
      ~TFRecordDatasetGenerator.get_tf_record_dataset
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TFRecordDatasetGenerator.feature_description
   
   